@@ -1,7 +1,7 @@
 #
 # This file is part of Dist-Zilla-PluginBundle-Author-Celogeek
 #
-# This software is copyright (c) 2011 by celogeek <me@celogeek.com>.
+# This software is copyright (c) 2014 by celogeek <me@celogeek.com>.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -13,7 +13,7 @@ package Dist::Zilla::PluginBundle::Author::Celogeek;
 use strict;
 use warnings;
 
-our $VERSION = '1.0';    # VERSION
+our $VERSION = '1.1';    # VERSION
 
 use Moose;
 use Class::MOP;
@@ -125,7 +125,7 @@ Dist::Zilla::PluginBundle::Author::Celogeek - Dist::Zilla like Celogeek
 
 =head1 VERSION
 
-version 1.0
+version 1.1
 
 =head1 OVERVIEW
 
@@ -249,8 +249,7 @@ Configuration of Dist::Zilla::PluginBundle::Easy
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://tasks.celogeek.com/projects/perl-modules-dist-zilla-pluginbundle-aut
-hor-celogeek
+https://github.com/celogeek/dist-zilla-pluginbundle-author-celogeek/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -262,7 +261,7 @@ celogeek <me@celogeek.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by celogeek <me@celogeek.com>.
+This software is copyright (c) 2014 by celogeek <me@celogeek.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
